%define python311_sitelib /usr/lib/python3.11/site-packages/
%define python3_pkgversion 3.11
%global pypi_name platformdirs
%global pypi_version 4.3.6

%bcond_with tests

Name:           python-%{pypi_name}
Version:        %{pypi_version}
Release:        1.0.1%{?dist}
Summary:        A small Python package for determining appropriate platform-specific dirs
License:        MIT
URL:            https://github.com/platformdirs/platformdirs
Source:         https://files.pythonhosted.org/packages/source/p/%{pypi_name}/%{pypi_name}-%{version}.tar.gz
# Oracle patches
Patch1001:	0001-Add-setup.py.patch
Patch1002:	0002-Update-project.toml-to-latest-specification.patch

BuildArch:      noarch

%global common_description %{expand:
When writing desktop application, finding the right location to store user data
and configuration varies per platform.  Even for single-platform apps, there
may by plenty of nuances in figuring out the right location.  This kind of
thing is what the platformdirs package is for.}


%description %{common_description}


%package -n python%{python3_pkgversion}-platformdirs
Summary:        %{summary}
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-rpm-macros

%description -n python%{python3_pkgversion}-platformdirs %{common_description}


%prep
%autosetup -n platformdirs-%{version}

# https://docs.fedoraproject.org/en-US/packaging-guidelines/Python/#_linters
sed -r -i '/^[[:blank:]]*"pytest-cov\b/d' pyproject.toml
sed -r -i '/^[[:blank:]]*"covdefaults\b/d' pyproject.toml
ln -s src/%{pypi_name} %{pypi_name}

%build
%py3_build


%install
%py3_install

%check
%if %{with tests}
# Upstream uses tox, but we don’t use it, to avoid a build dependency loop
# platformdirs <- virtualenv <- tox
%pytest
%endif

%files -n python%{python3_pkgversion}-platformdirs
%doc README.rst
%{python3_sitelib}/%{pypi_name}
%{python3_sitelib}/%{pypi_name}-%{version}-py%{python3_version}.egg-info


%changelog
* Fri Jan 17 2025 Rafael Barron <rafael.barron@oracle.com> - 4.3.6-1.0.1
- Update to 4.3.6

## START: Generated by rpmautospec
* Tue Aug 13 2024 Darren Archibald <darren.archibald@oracle.com> - 4.2.2-2.0.2
- Added missing links to python code.

* Fri Aug 02 2024 Darren Archibald <darren.archibald@oracle.com> - 4.2.2-2.0.1
- Modify the project to be buildable without pyproject toolset

* Fri Jul 19 2024 Fedora Release Engineering <releng@fedoraproject.org> - 4.2.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Tue Jul 09 2024 Carl George <carlwgeorge@fedoraproject.org> - 4.2.2-1
- Update to version 4.2.2 rhbz#2227426

* Fri Jun 07 2024 Python Maint <python-maint@redhat.com> - 3.11.0-4
- Rebuilt for Python 3.13

* Fri Jan 26 2024 Fedora Release Engineering <releng@fedoraproject.org> - 3.11.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Mon Jan 22 2024 Fedora Release Engineering <releng@fedoraproject.org> - 3.11.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sat Dec 02 2023 Orion Poplawski <orion@nwra.com> - 3.11.0-1
- Update to 3.11.0

* Fri Jul 21 2023 Fedora Release Engineering <releng@fedoraproject.org> - 3.9.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Mon Jul 17 2023 Lumír Balhar <lbalhar@redhat.com> - 3.9.1-1
- Update to 3.9.1 (rhbz#2156775)

* Fri Jun 30 2023 Tomáš Hrnčiar <thrnciar@redhat.com> - 3.5.1-1
- Update to 3.5.1
- Fixes: rhbz#2156775

* Tue Jun 13 2023 Python Maint <python-maint@redhat.com> - 2.6.0-3
- Rebuilt for Python 3.12

* Fri Jan 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Thu Dec 08 2022 Lumír Balhar <lbalhar@redhat.com> - 2.6.0-1
- Update to 2.6.0 (rhbz#2151438)

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.5.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jun 13 2022 Python Maint <python-maint@redhat.com> - 2.5.2-2
- Rebuilt for Python 3.11

* Thu Apr 21 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 2.5.2-1
- Update to 2.5.2; accommodate upstream’s switch to hatchling build backend
- Add a build conditional for the tests

* Tue Mar 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 2.5.1-1
- Update to 2.5.1 (close RHBZ#2007878)

* Fri Jan 21 2022 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Sat Dec 04 2021 Carl George <carl@george.computer> - 2.3.0-3
- Use "test" extra to generate buildrequires
- Run tests with %%pytest

* Tue Oct 26 2021 Miro Hrončok <mhroncok@redhat.com> - 2.3.0-2
- Don't use tox during the build to avoid a build dependency loop

* Mon Aug 30 2021 Carl George <carl@george.computer> - 2.3.0-1
- Latest upstream
- Resolves: rhbz#1999337

* Sun Aug 01 2021 Carl George <carl@george.computer> - 2.2.0-1
- Latest upstream
- Resolves: rhbz#1985567

* Fri Jul 23 2021 Miro Hrončok <mhroncok@redhat.com> - 2.0.0-3
- Let %%pyproject_buildrequires know we need appdirs

* Fri Jul 23 2021 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Mon Jul 12 2021 Carl George <carl@george.computer> - 2.0.0-1
- Initial package rhbz#1981607

## END: Generated by rpmautospec
